#!/usr/bin/env php
<?
include('bootstrap.php');

$args = getopt('rut', ['rules', 'unpublish', 'totals']);

if (count($args) == 0 || isset($args['h'])) {
    echo "\n";
    echo "avos.php [-r|--rules] [[-u|--unpublish] nick1 nick2 nickN]\n";
    echo "  -r|--rules:     check author rewrite rules and conditions\n";
    echo "  -t|--totals:    display total cams+viewers online over time\n";
    echo "  -u|--unpublish: unpublish models\n";
    echo "\n";
    echo "examples:\n";
    echo "  ./avos.php --rules\n";
    echo "  ./avos.php -u 005ckempulga_08 00littlered 0neboyxx\n";
    echo "  ./avos.php -t\n";
    echo "\n";
    exit;
}

//
// check/eval all author rule conditions
//

if (isset($args['r']) || isset($args['rules'])) {
    \Avos\Scaffold\readAuthorRules();
    $ret = \Avos\Scaffold\checkAllAuthorConds();
    echo "\nfound $ret[rules] rules, $ret[conditions] had conditions and $ret[failed] failed\n";

    if (count($ret['failures'])) {
        echo "\n";
        foreach ($ret['failures'] as $fail) {
            echo "$fail[error] error, $fail[condition]\n";
        }
        echo "\n";
    }
}

//
// display snapshots of models vs viewers against time
//

else if (isset($args['t']) || isset($args['totals'])) {
    $tot = \Avos\Redis\get('^avos/webcams/totals');

    printf("date        time      %10s %10s     %10s\n", 'models', 'viewers', 'viewers/models');
    foreach ($tot['snapshots'] as $t => $d) {
        if (preg_match('!(\d\d)(\d\d)(\d\d)(\d\d)!', $t, $c)) {
            printf("$c[1]/$c[2]/$c[3]    $c[4]:00    %10s %10s %10.2f\n", $d[0], $d[1], $d[1] / $d[0]);
        }
    }
}

//
// unpublish models
//

else if (isset($args['u']) || isset($args['unpublsh'])) {

    if (AVOS_DB_NAME != AVOS_DB_CAMS) {
        echo "unable to run on satellite site\n";
        exit(1);
    }

    for ($i=2; $i<$argc; $i++) {

        $nickname = $argv[$i];

        $chk = \Avos\Database\queryAssoc("SELECT id FROM webcamsArchive WHERE nickname=:nickname",
            [ 'nickname' => $nickname ]
        );

        if (count($chk) == 0) {
            echo "$nickname: not found\n";
        }
        else {
            foreach ($chk as $m) {
                \Avos\Database\query("UPDATE webcamsArchive SET updatedOn=0 WHERE id=:id", $m);
                echo "$nickname: $m[id] unpublished\n";
            }
        }
    }
}

